@@ -11,9 +11,12 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+	"github.com/tidwall/gjson"
 
 	"github.com/infracost/infracost/internal/config"
+	"github.com/infracost/infracost/internal/schema"
 	"github.com/infracost/infracost/internal/testutil"
 )
 
@@ -53,7 +56,7 @@ func TestBreakdownFormatJsonWithWarnings(t *testing.T) {
 			"--format", "json",
 			"--path", dir,
 		},
-		DefaultOptions(),
+		&GoldenFileOptions{CaptureLogs: true},
 	)
 }
 
@@ -335,7 +338,13 @@ func TestBreakdownTerragruntHCLMulti(t *testing.T) {
 }
 
 func TestBreakdownTerragruntHCLDepsOutput(t *testing.T) {
-	GoldenFileCommandTest(t, testutil.CalcGoldenFileTestdataDirName(), []string{"breakdown", "--path", path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())}, nil)
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{"breakdown", "--path",
+			path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())},
+		&GoldenFileOptions{CaptureLogs: true},
+	)
 }
 
 func TestBreakdownTerragruntGetEnv(t *testing.T) {
@@ -458,6 +467,75 @@ func TestBreakdownWithPrivateTerraformRegistryModule(t *testing.T) {
 	)
 }
 
+func TestBreakdownWithPrivateSshModulePopulatesErrors(t *testing.T) {
+	output := GetCommandOutput(
+		t,
+		[]string{
+			"breakdown",
+			"--path",
+			path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName()),
+			"--format",
+			"json",
+		},
+		nil,
+	)
+
+	res := gjson.ParseBytes(output)
+	errs := res.Get("projects.0.metadata.errors").Array()
+	require.Len(t, errs, 1)
+
+	code := errs[0].Get("code").Int()
+	msg := errs[0].Get("message").String()
+	data := errs[0].Get("data").Map()
+
+	assert.Equal(t, schema.DiagPrivateModuleDownloadFailure, int(code))
+	assert.Contains(t, msg, "Failed to download remote module \"ec2_cluster\"")
+	assert.Equal(t, data["source"].String(), "ssh")
+}
+
+func TestBreakdownWithPrivateHttpsModulePopulatesErrors(t *testing.T) {
+	output := GetCommandOutput(
+		t,
+		[]string{
+			"breakdown",
+			"--path",
+			path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName()),
+			"--format",
+			"json",
+		},
+		nil,
+	)
+
+	res := gjson.ParseBytes(output)
+	errs := res.Get("projects.0.metadata.errors").Array()
+	require.Len(t, errs, 1)
+
+	code := errs[0].Get("code").Int()
+	msg := errs[0].Get("message").String()
+	data := errs[0].Get("data").Map()
+
+	assert.Equal(t, schema.DiagPrivateModuleDownloadFailure, int(code))
+	assert.Contains(t, msg, "Failed to download remote module \"ec2_cluster\"")
+	assert.Equal(t, data["source"].String(), "https")
+}
+
+func TestBreakdownWithPrivateTerraformRegistryModulePopulatesErrors(t *testing.T) {
+	t.Setenv("INFRACOST_TERRAFORM_CLOUD_TOKEN", "badkey")
+
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path",
+			path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName()),
+			"--format",
+			"json",
+		},
+		nil,
+	)
+}
+
 func TestBreakdownWithWorkspace(t *testing.T) {
 	GoldenFileCommandTest(
 		t,
