@@ -61,6 +61,22 @@ func GoldenFileCommandTest(t *testing.T, testName string, args []string, testOpt
 }
 
 func goldenFileCommandTest(t *testing.T, testName string, args []string, testOptions *GoldenFileOptions, hcl bool, ctxOptions ...func(ctx *config.RunContext)) {
+	actual := GetCommandOutput(t, args, testOptions, ctxOptions...)
+
+	goldenFilePath := filepath.Join("testdata", testName, testName+".golden")
+	if hcl {
+		hclFilePath := filepath.Join("testdata", testName, testName+".hcl.golden")
+		_, err := os.Stat(hclFilePath)
+		if err == nil {
+			testutil.AssertGoldenFile(t, hclFilePath, actual)
+			return
+		}
+	}
+
+	testutil.AssertGoldenFile(t, goldenFilePath, actual)
+}
+
+func GetCommandOutput(t *testing.T, args []string, testOptions *GoldenFileOptions, ctxOptions ...func(ctx *config.RunContext)) []byte {
 	t.Helper()
 
 	if testOptions == nil {
@@ -133,19 +149,7 @@ func goldenFileCommandTest(t *testing.T, testName string, args []string, testOpt
 		actual = append(actual, logBuf.Bytes()...)
 	}
 
-	actual = stripDynamicValues(actual)
-
-	goldenFilePath := filepath.Join("testdata", testName, testName+".golden")
-	if hcl {
-		hclFilePath := filepath.Join("testdata", testName, testName+".hcl.golden")
-		_, err := os.Stat(hclFilePath)
-		if err == nil {
-			testutil.AssertGoldenFile(t, hclFilePath, actual)
-			return
-		}
-	}
-
-	testutil.AssertGoldenFile(t, goldenFilePath, actual)
+	return stripDynamicValues(actual)
 }
 
 // stripDynamicValues strips out any values that change between test runs from the output,
