@@ -16,9 +16,10 @@ import (
 	"github.com/shopspring/decimal"
 	"golang.org/x/mod/semver"
 
+	log "github.com/sirupsen/logrus"
+
 	"github.com/infracost/infracost/internal/clierror"
 	"github.com/infracost/infracost/internal/schema"
-	log "github.com/sirupsen/logrus"
 )
 
 var (
@@ -127,8 +128,25 @@ func CompareTo(current, prior Root) (Root, error) {
 		scp.HasDiff = true
 
 		if v, ok := priorProjects[p.LabelWithMetadata()]; ok {
-			scp.PastResources = v.Resources
-			scp.Diff = schema.CalculateDiff(scp.PastResources, scp.Resources)
+			if !p.Metadata.HasErrors() && !v.Metadata.HasErrors() {
+				scp.PastResources = v.Resources
+				scp.Diff = schema.CalculateDiff(scp.PastResources, scp.Resources)
+			}
+
+			if !p.Metadata.HasErrors() && v.Metadata.HasErrors() {
+				// the prior project has errors, but the current one does not
+				// The prior errors will be copied over to the current, but we
+				// also need to remove the current project costs
+				scp.Resources = nil
+				scp.Diff = nil
+				scp.HasDiff = false
+			}
+
+			for _, pastE := range v.Metadata.Errors {
+				pastE.Message = "Diff baseline error: " + pastE.Message
+				scp.Metadata.Errors = append(scp.Metadata.Errors, pastE)
+			}
+
 			delete(priorProjects, p.LabelWithMetadata())
 		}
 
@@ -151,6 +169,20 @@ func CompareTo(current, prior Root) (Root, error) {
 		return out, err
 	}
 
+	// preserve the summary from the original run
+	currentProjects := make(map[string]Project)
+	for _, p := range prior.Projects {
+		currentProjects[p.LabelWithMetadata()] = p
+	}
+	for _, outP := range out.Projects {
+		if v, ok := currentProjects[outP.LabelWithMetadata()]; ok {
+			outP.Summary = v.Summary
+			outP.fullSummary = v.fullSummary
+		}
+	}
+
+	out.Summary = current.Summary
+	out.FullSummary = current.FullSummary
 	out.Currency = current.Currency
 	return out, nil
 }
