@@ -25,6 +25,13 @@ func NewDBInstance(d *schema.ResourceData) schema.CoreResource {
 		}
 	}
 
+	iops := d.Get("iops").Float()
+	defaultStorageType := "gp2"
+	if iops > 0 {
+		defaultStorageType = "io1"
+	}
+
+	storageType := d.GetStringOrDefault("storage_type", defaultStorageType)
 	r := &aws.DBInstance{
 		Address:                              d.Address,
 		Region:                               d.Get("region").String(),
@@ -33,8 +40,8 @@ func NewDBInstance(d *schema.ResourceData) schema.CoreResource {
 		MultiAZ:                              d.Get("multi_az").Bool(),
 		LicenseModel:                         d.Get("license_model").String(),
 		BackupRetentionPeriod:                d.Get("backup_retention_period").Int(),
-		IOPS:                                 d.Get("iops").Float(),
-		StorageType:                          d.Get("storage_type").String(),
+		IOPS:                                 iops,
+		StorageType:                          storageType,
 		PerformanceInsightsEnabled:           piEnabled,
 		PerformanceInsightsLongTermRetention: piLongTerm,
 	}
