@@ -11,7 +11,5 @@ func TestNewAzureRMSynapseSparkPool(t *testing.T) {
 		t.Skip("skipping test in short mode")
 	}
 
-	tftest.GoldenFileResourceTestsWithOpts(t, "synapse_spark_pool_test", &tftest.GoldenFileOptions{
-		CaptureLogs: true,
-	})
+	tftest.GoldenFileResourceTests(t, "synapse_spark_pool_test")
 }
