@@ -12,7 +12,6 @@ import (
 	"github.com/pkg/errors"
 	"github.com/tidwall/gjson"
 
-	address_parser "github.com/hashicorp/go-terraform-address"
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/providers/terraform/aws"
@@ -89,7 +88,7 @@ func (p *Parser) createPartialResource(d *schema.ResourceData, u *schema.UsageDa
 	}
 }
 
-func (p *Parser) parseJSONResources(parsePrior bool, baseResources []*schema.PartialResource, usage map[string]*schema.UsageData, parsed, providerConf, conf, vars gjson.Result) []*schema.PartialResource {
+func (p *Parser) parseJSONResources(parsePrior bool, baseResources []*schema.PartialResource, usage schema.UsageMap, parsed, providerConf, conf, vars gjson.Result) []*schema.PartialResource {
 	var resources []*schema.PartialResource
 	resources = append(resources, baseResources...)
 	var vals gjson.Result
@@ -109,7 +108,6 @@ func (p *Parser) parseJSONResources(parsePrior bool, baseResources []*schema.Par
 	resData := p.parseResourceData(isState, providerConf, vals, conf, vars)
 
 	p.parseReferences(resData, conf)
-	p.loadInfracostProviderUsageData(usage, resData)
 	p.stripDataResources(resData)
 	p.populateUsageData(resData, usage)
 
@@ -124,34 +122,13 @@ func (p *Parser) parseJSONResources(parsePrior bool, baseResources []*schema.Par
 
 // populateUsageData finds the UsageData for each ResourceData and sets the ResourceData.UsageData field
 // in case it is needed when processing a reference attribute
-func (p *Parser) populateUsageData(resData map[string]*schema.ResourceData, usage map[string]*schema.UsageData) {
+func (p *Parser) populateUsageData(resData map[string]*schema.ResourceData, usage schema.UsageMap) {
 	for _, d := range resData {
-		// Look and default to resource_type level data
-		parsed_address, err := address_parser.NewAddress(d.Address)
-		if err == nil {
-			val, ok := usage[parsed_address.ResourceSpec.Type]
-			if ok {
-				d.UsageData = val
-			}
-		}
-
-		if ud := usage[d.Address]; ud != nil {
-			if d.UsageData != nil {
-				schema.MergeAttributes(d.UsageData, ud)
-			} else {
-				d.UsageData = ud
-			}
-		} else if strings.HasSuffix(d.Address, "]") {
-			lastIndexOfOpenBracket := strings.LastIndex(d.Address, "[")
-
-			if arrayUsageData := usage[fmt.Sprintf("%s[*]", d.Address[:lastIndexOfOpenBracket])]; arrayUsageData != nil {
-				d.UsageData = arrayUsageData
-			}
-		}
+		d.UsageData = usage.Get(d.Address)
 	}
 }
 
-func (p *Parser) parseJSON(j []byte, usage map[string]*schema.UsageData) ([]*schema.PartialResource, []*schema.PartialResource, error) {
+func (p *Parser) parseJSON(j []byte, usage schema.UsageMap) ([]*schema.PartialResource, []*schema.PartialResource, error) {
 	baseResources := p.loadUsageFileResources(usage)
 
 	j, _ = StripSetupTerraformWrapper(j)
@@ -172,7 +149,7 @@ func (p *Parser) parseJSON(j []byte, usage map[string]*schema.UsageData) ([]*sch
 		return nil, resources, nil
 	}
 
-	if parsed.Get("prior_state").Exists() == false {
+	if !parsed.Get("prior_state").Exists() {
 		return nil, resources, nil
 	}
 
@@ -203,10 +180,10 @@ func StripSetupTerraformWrapper(b []byte) ([]byte, bool) {
 	return stripped, len(stripped) != len(b)
 }
 
-func (p *Parser) loadUsageFileResources(u map[string]*schema.UsageData) []*schema.PartialResource {
+func (p *Parser) loadUsageFileResources(u schema.UsageMap) []*schema.PartialResource {
 	resources := make([]*schema.PartialResource, 0)
 
-	for k, v := range u {
+	for k, v := range u.Data() {
 		for _, t := range GetUsageOnlyResources() {
 			if strings.HasPrefix(k, fmt.Sprintf("%s.", t)) {
 				d := schema.NewResourceData(t, "global", k, map[string]string{}, gjson.Result{})
@@ -461,24 +438,6 @@ func parseRegion(providerConf gjson.Result, vars gjson.Result, providerKey strin
 	return region
 }
 
-func (p *Parser) loadInfracostProviderUsageData(u map[string]*schema.UsageData, resData map[string]*schema.ResourceData) {
-	logging.Logger.Debugf("Loading usage data from Infracost provider resources")
-
-	for _, d := range resData {
-		if isInfracostResource(d) {
-			p.ctx.SetContextValue("terraformInfracostProviderEnabled", true)
-
-			for _, ref := range d.References("resources") {
-				if _, ok := u[ref.Address]; !ok {
-					u[ref.Address] = schema.NewUsageData(ref.Address, convertToUsageAttributes(d.RawValues))
-				} else {
-					logging.Logger.Debugf("Skipping loading usage for resource %s since it has already been defined", ref.Address)
-				}
-			}
-		}
-	}
-}
-
 func (p *Parser) stripDataResources(resData map[string]*schema.ResourceData) {
 	for addr, d := range resData {
 		if strings.HasPrefix(addressResourcePart(d.Address), "data.") {
@@ -633,16 +592,6 @@ func (p *Parser) parseConfReferences(resData map[string]*schema.ResourceData, co
 	return found
 }
 
-func convertToUsageAttributes(j gjson.Result) map[string]gjson.Result {
-	a := make(map[string]gjson.Result)
-
-	for k, v := range j.Map() {
-		a[k] = v.Get("0.value")
-	}
-
-	return a
-}
-
 func getConfJSON(conf gjson.Result, addr string) gjson.Result {
 	modNames := getModuleNames(addr)
 	c := getModuleConfJSON(conf, modNames)
@@ -861,5 +810,5 @@ func gjsonEqual(a, b gjson.Result) bool {
 		return false
 	}
 
-	return string(aOut.Bytes()) == string(bOut.Bytes())
+	return aOut.String() == bOut.String()
 }
