@@ -2,10 +2,13 @@ package aws
 
 import (
 	"fmt"
+	"strings"
+
+	"github.com/shopspring/decimal"
+	log "github.com/sirupsen/logrus"
+
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
-	"github.com/shopspring/decimal"
-	"strings"
 )
 
 type RDSClusterInstance struct {
@@ -15,15 +18,19 @@ type RDSClusterInstance struct {
 	Engine                                       string
 	PerformanceInsightsEnabled                   bool
 	PerformanceInsightsLongTermRetention         bool
-	MonthlyCPUCreditHrs                          *int64 `infracost_usage:"monthly_cpu_credit_hrs"`
-	VCPUCount                                    *int64 `infracost_usage:"vcpu_count"`
-	MonthlyAdditionalPerformanceInsightsRequests *int64 `infracost_usage:"monthly_additional_performance_insights_requests"`
+	MonthlyCPUCreditHrs                          *int64  `infracost_usage:"monthly_cpu_credit_hrs"`
+	VCPUCount                                    *int64  `infracost_usage:"vcpu_count"`
+	MonthlyAdditionalPerformanceInsightsRequests *int64  `infracost_usage:"monthly_additional_performance_insights_requests"`
+	ReservedInstanceTerm                         *string `infracost_usage:"reserved_instance_term"`
+	ReservedInstancePaymentOption                *string `infracost_usage:"reserved_instance_payment_option"`
 }
 
 var RDSClusterInstanceUsageSchema = []*schema.UsageItem{
 	{Key: "monthly_cpu_credit_hrs", ValueType: schema.Int64, DefaultValue: 0},
 	{Key: "vcpu_count", ValueType: schema.Int64, DefaultValue: 0},
 	{Key: "monthly_additional_performance_insights_requests", ValueType: schema.Int64, DefaultValue: 0},
+	{Key: "reserved_instance_term", DefaultValue: "", ValueType: schema.String},
+	{Key: "reserved_instance_payment_option", DefaultValue: "", ValueType: schema.String},
 }
 
 func (r *RDSClusterInstance) PopulateUsage(u *schema.UsageData) {
@@ -33,9 +40,27 @@ func (r *RDSClusterInstance) PopulateUsage(u *schema.UsageData) {
 func (r *RDSClusterInstance) BuildResource() *schema.Resource {
 	databaseEngine := r.databaseEngineValue()
 
+	purchaseOptionLabel := "on-demand"
+	priceFilter := &schema.PriceFilter{
+		PurchaseOption: strPtr("on_demand"),
+	}
+
+	var err error
+	if r.ReservedInstanceTerm != nil {
+		resolver := &rdsReservationResolver{
+			term:          strVal(r.ReservedInstanceTerm),
+			paymentOption: strVal(r.ReservedInstancePaymentOption),
+		}
+		priceFilter, err = resolver.PriceFilter()
+		if err != nil {
+			log.Warnf(err.Error())
+		}
+		purchaseOptionLabel = "reserved"
+	}
+
 	costComponents := []*schema.CostComponent{
 		{
-			Name:           fmt.Sprintf("Database instance (%s, %s)", "on-demand", r.InstanceClass),
+			Name:           fmt.Sprintf("Database instance (%s, %s)", purchaseOptionLabel, r.InstanceClass),
 			Unit:           "hours",
 			UnitMultiplier: decimal.NewFromInt(1),
 			HourlyQuantity: decimalPtr(decimal.NewFromInt(1)),
@@ -49,9 +74,7 @@ func (r *RDSClusterInstance) BuildResource() *schema.Resource {
 					{Key: "databaseEngine", Value: strPtr(databaseEngine)},
 				},
 			},
-			PriceFilter: &schema.PriceFilter{
-				PurchaseOption: strPtr("on_demand"),
-			},
+			PriceFilter: priceFilter,
 		},
 	}
 
@@ -94,14 +117,11 @@ func (r *RDSClusterInstance) BuildResource() *schema.Resource {
 }
 
 func (r *RDSClusterInstance) databaseEngineValue() string {
-	switch r.Engine {
-	case "aurora", "aurora-mysql", "":
-		return "Aurora MySQL"
-	case "aurora-postgresql":
+	if r.Engine == "aurora-postgresql" {
 		return "Aurora PostgreSQL"
 	}
 
-	return ""
+	return "Aurora MySQL"
 }
 
 func (r *RDSClusterInstance) cpuCreditsCostComponent(databaseEngine, instanceFamily string, vCPUCount decimal.Decimal) *schema.CostComponent {
